LamsonProject: Lamson Releases

#

# Lamson Releases

You can get the Lamson source in various ways:

- Download it from the Launchpad project page
- Use Bazaar to get the code with bzr branch lp:lamson

And don’t forget you can install it with easy_install as well:

    sudo easy_install --upgrade lamson

> If easy_install doesn’t work, try without —upgrade, and if that doesn’t work then look in your site-packages directory and delete all the versions of Lamson you find.

## Releases

You can get the 0.9.4 release source from the this site as well:

0.9.4 release tar.gz

0.9.4 release Python Egg

This version has been tested, but it is a fairly big change from the 0.8.x series. You should be able to migrate your code to 0.9.4 quickly, but you’ll want to read through the documentation, and I hope you had tests for everything.

## Examples

You can get the One-Shot-Blog example by grabbing the above source, untarring it, and then look in example/osb.